==> sqlentity-2.1.2.tar.gz: example/lib/main.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:sqlentity/base-entity/entity.dart';
import 'package:sqlentity/database/database-config.dart';
import 'package:sqlentity/repository/dao-repository/dao-repository.dart';
import 'package:sqlentity/repository/dao-repository/i-dao-repository.dart';

void main() => runApp(new MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => new _MyAppState();
}

class _MyAppState extends State<MyApp> {
  List<UserEntity> users = new List();
  IDAORepository<UserEntity> _idao;
  List<int> listint = [
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ];

  @override
  void initState() {
    super.initState();
    initDatabase();
    _idao = new DAORepository(new UserEntity());
    initData();
    initData2();
    initData3();
  }

  void initDatabase() {
    DataBaseConfig dataBaseConfig = DataBaseConfig();
    dataBaseConfig.database_name = "Teste0";
    dataBaseConfig.database_version = 1;
    dataBaseConfig.entitys = [new UserEntity()];
  }

  void initData() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  void initData2() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  void initData3() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      home: new Scaffold(
          appBar: new AppBar(
            title: const Text('DataBase'),
          ),
          body: new ListView.builder(
              padding: new EdgeInsets.all(4.0),
              shrinkWrap: true,
              itemCount: users.length,
              itemBuilder: (context, index) {
                return new Container(
                    margin: new EdgeInsets.all(8.0),
                    child: new Center(
                        child: new Text(
                      '${users[index].name}, ${users[index].sobrename}',
                      style: new TextStyle(
                          color: Colors.green,
                          fontWeight: FontWeight.bold,
                          fontSize: 18),
                    )));
              })),
    );
  }
}

class UserEntity extends Entity {
  int _id;
  String _name;
  String _sobrename;

  UserEntity({var id: 0, var name: "", var sobrename: ""}) : super('USER') {
    this.id = id;
    this.name = name;
    this.sobrename = sobrename;
  }

  @override
  void configColumn() {
    //O id deve ser sempre o primeiro caso queira usar as operaçoes padroes do DAO
    createColumn("ID", "INTEGER PRIMARY KEY AUTOINCREMENT", 1);

    //nova coluna
    createColumn("NAME", "TEXT UNIQUE", 1);
    createColumn("SOBRENAME", "TEXT", 1);
  }

  @override
  Entity map(Map<String, dynamic> map) {
    return new UserEntity(
      id: map['ID'],
      name: map['NAME'],
      sobrename: map['SOBRENAME'],
    );
  }

  int get id => _id;

  set id(int value) {
    _id = value;
    updateValeu("ID", value: id);
  }

  String get name => _name;

  set name(String value) {
    _name = value;
    updateValeu("NAME", value: _name);
  }

  String get sobrename => _sobrename;

  set sobrename(String value) {
    _sobrename = value;
    updateValeu("SOBRENAME", value: _sobrename);
  }
}

==> sqlentity-2.1.3.tar.gz: example/lib/main.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:sqlentity/base-entity/entity.dart';
import 'package:sqlentity/database/database-config.dart';
import 'package:sqlentity/repository/dao-repository/dao-repository.dart';
import 'package:sqlentity/repository/dao-repository/i-dao-repository.dart';

void main() => runApp(new MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => new _MyAppState();
}

class _MyAppState extends State<MyApp> {
  List<UserEntity> users = new List();
  IDAORepository<UserEntity> _idao;
  IDAORepository<UserEntity> _idao2;
  IDAORepository<UserEntity> _idao3;
  List<int> listint = [
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ];

  @override
  void initState() {
    super.initState();
    initDatabase();
    _idao = new DAORepository(new UserEntity());
    _idao2 = new DAORepository(new UserEntity());
    _idao3 = new DAORepository(new UserEntity());
    initData();
    initData2();
    initData3();
  }

  void initDatabase() {
    DataBaseConfig dataBaseConfig = DataBaseConfig();
    dataBaseConfig.database_name = "tes.db";
    dataBaseConfig.database_version = 1;
    dataBaseConfig.entitys = [new UserEntity()];
  }

  void initData() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });

    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao3.insert(dart);
      _idao3.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao3.update(dart);
      _idao3.select();
      var userlist = await _idao3.select();
      var getById = await _idao3.getById(dart);
      var count = await _idao3.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });

    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao2.insert(dart);
      _idao2.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao2.update(dart);
      _idao2.select();
      var userlist = await _idao2.select();
      var getById = await _idao2.getById(dart);
      var count = await _idao2.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  void initData2() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  void initData3() async {
    listint.forEach((element) async {
      UserEntity dart = new UserEntity(
          name: Random().nextInt(10000).toString(),
          sobrename: Random().nextInt(10000).toString());
      int iddart = await _idao.insert(dart);
      _idao.select();
      dart.id = iddart;
      dart.sobrename = Random().nextInt(10000).toString();
      _idao.update(dart);
      _idao.select();
      var userlist = await _idao.select();
      var getById = await _idao.getById(dart);
      var count = await _idao.count();
      if (userlist?.length == count) userlist?.add(getById);
      setState(() {
        users = userlist;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      home: new Scaffold(
          appBar: new AppBar(
            title: const Text('DataBase'),
          ),
          body: new ListView.builder(
              padding: new EdgeInsets.all(4.0),
              shrinkWrap: true,
              itemCount: users.length,
              itemBuilder: (context, index) {
                return new Container(
                    margin: new EdgeInsets.all(8.0),
                    child: new Center(
                        child: new Text(
                      '${users[index].name}, ${users[index].sobrename}',
                      style: new TextStyle(
                          color: Colors.green,
                          fontWeight: FontWeight.bold,
                          fontSize: 18),
                    )));
              })),
    );
  }
}

class UserEntity extends Entity {
  int _id;
  String _name;
  String _sobrename;

  UserEntity({var id: 0, var name: "", var sobrename: ""}) : super('USER') {
    this.id = id;
    this.name = name;
    this.sobrename = sobrename;
  }

  @override
  void configColumn() {
    //O id deve ser sempre o primeiro caso queira usar as operaçoes padroes do DAO
    createColumn("ID", "INTEGER PRIMARY KEY AUTOINCREMENT", 1);

    //nova coluna
    createColumn("NAME", "TEXT UNIQUE", 1);
    createColumn("SOBRENAME", "TEXT", 1);
  }

  @override
  Entity map(Map<String, dynamic> map) {
    return new UserEntity(
      id: map['ID'],
      name: map['NAME'],
      sobrename: map['SOBRENAME'],
    );
  }

  int get id => _id;

  set id(int value) {
    _id = value;
    updateValeu("ID", value: id);
  }

  String get name => _name;

  set name(String value) {
    _name = value;
    updateValeu("NAME", value: _name);
  }

  String get sobrename => _sobrename;

  set sobrename(String value) {
    _sobrename = value;
    updateValeu("SOBRENAME", value: _sobrename);
  }
}
